<?php 
$OC_Version = array(25,0,6,1);
$OC_VersionString = '25.0.6';
$OC_Edition = '';
$OC_Channel = 'stable';
$OC_VersionCanBeUpgradedFrom = array (
  'nextcloud' => 
  array (
    '24.0' => true,
    '25.0' => true,
  ),
  'owncloud' => 
  array (
    '10.11' => true,
  ),
);
$OC_Build = '2023-04-19T15:56:33+00:00 df9a14d1d63ad8f46d65c19c67736ef922bdbdfe';
$vendor = 'nextcloud';
